@@ -3,6 +3,7 @@ import subprocess
 import time
 from pathlib import Path
 from typing import Dict, Generator, Iterator
+from urllib.parse import quote
 
 import pytest
 from playwright.sync_api import BrowserContext, Page, expect
@@ -137,15 +138,16 @@ def save_trace(page: Page, context: BrowserContext, request: pytest.FixtureReque
             subfolder = f"{ucr.get('hostname')}/"
         else:
             subfolder = ""
-        browser_trace_url = f"{os.environ['JENKINS_WS']}ws/test/{subfolder}browser/{trace_filename.name}"
-        browser_screenshot_url = f"{os.environ['JENKINS_WS']}ws/test/{subfolder}browser/{screenshot_filename.name}"
+
+        browser_trace_url = f"{os.environ['JENKINS_WS']}ws/test/{quote(subfolder)}browser/{quote(trace_filename.name)}"
+        browser_screenshot_url = f"{os.environ['JENKINS_WS']}ws/test/{quote(subfolder)}browser/{quote(screenshot_filename.name)}"
         logger.info("Browser trace URL: %s" % browser_trace_url)
         logger.info("Browser screenshot URL: %s" % browser_screenshot_url)
 
 
 def check_for_backtrace(page: Page):
     show_backtrace_button = page.get_by_role("button", name="Show server error message")
-    notification_502_error = page.get_by_text("An unknown error with status code 502 occurred")
+    notification_502_error = page.get_by_text("An unknown error with status code 502 occurred").first
     try:
         expect(show_backtrace_button.or_(notification_502_error)).to_be_visible(timeout=5 * SEC)
         if show_backtrace_button.is_visible():
